##  Dashboard Templates
You can activate onboarding dashboards and make them available to all workspace users as templates. To do that, in the Templates settings group, click Add template for the template that you want to add, then confirm your action.
Once added, the dashboard template appears in the All Dashboards and User-Defined sections of the dashboards page. This doesn’t replace or delete existing dashboards of the selected type. Adding a template that was added previously creates a new dashboard version. Users can modify the dashboard or create a new one from the template.
To learn more about onboarding dashboards, refer to:
  * [Fact Sheet Owner Onboarding Dashboard](https://help.sap.com/docs/leanix/ea/fact-sheet-owner-onboarding-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "The Fact Sheet Owner onboarding dashboard helps new users learn SAP LeanIX. It offers resources and panels for understanding responsibilities, managing data, and collaborating. It's the default dashboard for new workspaces, featuring tutorials and links to product documentation.")
  * [Application Portfolio Management Onboarding Dashboard for Enterprise Architects](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD "The Application Portfolio Management Onboarding Dashboard for enterprise architects streamlines the process of onboarding to SAP LeanIX Application Portfolio Management.")


YesNo
Send
